@@ -1,11 +1,10 @@
-from palp.item.item_base import BaseItem
+from palp.item.item_base import Item
 from palp.network.request import Request
 from palp.network.response import Response
-from palp.spider.spider_base import BaseSpider
+from palp.pipeline.pipeline_base import Pipeline
 from palp.spider import Spider, DistributiveSpider
-from palp.pipeline.pipeline_base import BasePipeline
 from palp.network.request_method import RequestGet, RequestPost
 from palp.conn.conn_redis import Redis, RedisLock, RedisLockNoWait
-from palp.middleware.middleware_spider_base import BaseSpiderMiddleware
-from palp.middleware.middleware_request_base import BaseRequestMiddleware
+from palp.middleware.middleware_spider_base import SpiderMiddleware
+from palp.middleware.middleware_request_base import RequestMiddleware
 from palp.exception.exception_drop import DropItemException, DropRequestException
